# Mixed Content Test

This file should be served with a content type of 'text/html'.

A 304 should be returned on subsequent requests, until you touch the file.

A content type for 'text/xml' should be returned for this file.

For a test of using Python builtin string substitution try this file.

For a test of using Kid templates this file. (Requires Kid)

For a test of using genshi templates this file.